
/**
  @addtogroup BLE_CONNCHIP Connectivity chip peripheral access service
  @{
  @brief  Definitions and prototypes for the connectivity chip peripheral access service interface.
 */

#ifndef BLE_CONNCHIP_H__
#define BLE_CONNCHIP_H__

#include "ble_types.h"
#include "ble_ranges.h"

#ifdef __cplusplus
extern "C" {
#endif

/** @addtogroup BLE_CONNCHIP_ENUMERATIONS Enumerations
 * @{ */

/**
 * @brief CONNCHIP API SVC numbers.
 */
enum BLE_CONN_CHIP_SVCS
{
  SD_BLE_CONN_CHIP_REG_SET  = BLE_CONNCHIP_SVC_BASE, /**< set a register */
  SD_BLE_CONN_CHIP_REG_GET, /**< get the value of a register */
};

/** @} */

typedef struct {
    volatile uint32_t * addr;   /**< register address on connectivity chip */
    uint32_t val;               /**< value to write in address on connectivity chip */
} ble_conn_chip_reg_set_t;

typedef struct {
    volatile const uint32_t * reg_addr;  /**< register address on connectivity chip */
    volatile       uint32_t * res_addr;  /**< result address on application chip */
} ble_conn_chip_reg_get_t;

uint32_t sd_ble_conn_chip_reg_set( ble_conn_chip_reg_set_t reg_set );
uint32_t sd_ble_conn_chip_reg_get( ble_conn_chip_reg_get_t reg_get );

#ifdef __cplusplus
}
#endif
#endif // BLE_CONNCHIP_H__
/**
  @}
*/
